namespace NUnitTests{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using Guia.Core;
    using Guia.Elements;
    using NUnit.Framework;
    using WpfTestApplication;

    /// <summary>
    /// Summary description for ComboBoxTest
    /// </summary>
    [TestFixture]
    public class ComboBoxTest : AbstractWindowTest
    {
        protected override Type TestWindowType()
        {
            return typeof(ComboBoxTestWindow);
        }

        protected override string TestWindowName()
        {
            return "ComboBoxTestWindow";
        }

        [Test]
        public void TestExpandCollapse()
        {
            ComboBox comboBox = window.Get<ComboBox>("comboBox1");
            Assert.IsFalse(comboBox.IsExpanded);
            comboBox.Expand();
            Assert.IsTrue(comboBox.IsExpanded);
            comboBox.Collapse();
            Assert.IsFalse(comboBox.IsExpanded);
            comboBox.IsExpanded = true;
            Assert.IsTrue(comboBox.IsExpanded);
            comboBox.IsExpanded = true;
            Assert.IsTrue(comboBox.IsExpanded);
            comboBox.IsExpanded = false;
            Assert.IsFalse(comboBox.IsExpanded);
            comboBox.IsExpanded = false;
            Assert.IsFalse(comboBox.IsExpanded);
        }

        [Test]
        public void TestGetSelectedItem()
        {
            ComboBox comboBox = window.Get<ComboBox>("comboBox1");
            ComboBoxItem selItem = comboBox.SelectedItem;
            Assert.IsNull(selItem);
            comboBox.GetItem("item 1").Select();
            selItem = comboBox.SelectedItem;
            Assert.IsNotNull(selItem);
            Assert.AreEqual("item 1", selItem.TextValue);

            comboBox.GetItem("item 2").Select();
            selItem = comboBox.SelectedItem;
            Assert.IsNotNull(selItem);
            Assert.AreEqual("item 2", selItem.TextValue);
        }

        [Test]
        public void TestGetItems()
        {
            ComboBox comboBox = window.Get<ComboBox>("comboBox1");
            ComboBoxItem[] items = comboBox.Items;
            Assert.AreEqual(3,items.Length);
            Assert.AreEqual("item 1",items[0].TextValue);
            Assert.AreEqual("item 2", items[1].TextValue);
            Assert.AreEqual("item 3", items[2].TextValue);
        }

        [Test]
        public void TestGetItemsIntIndexer()
        {
            ComboBox comboBox = window.Get<ComboBox>("comboBox1");
            Assert.AreEqual("item 1", comboBox[0].TextValue);
            Assert.AreEqual("item 2", comboBox[1].TextValue);
            Assert.AreEqual("item 3", comboBox[2].TextValue);
        }

        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void TestGetItemsIntIndexerInvalidValue()
        {
            ComboBox comboBox = window.Get<ComboBox>("comboBox1");
            ComboBoxItem item = comboBox[-1];
        }

        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void TestGetItemsIndexerNotFound()
        {
            ComboBox comboBox = window.Get<ComboBox>("comboBox1");
            Assert.AreEqual("item 1", comboBox[3].TextValue);
        }

        [Test]
        public void TestContains()
        {
            ComboBox comboBox = window.Get<ComboBox>("comboBox1");
            Assert.IsTrue(comboBox.Contains("item 1"));
            Assert.IsTrue(comboBox.Contains("item 2"));
            Assert.IsTrue(comboBox.Contains("item 3"));
            Assert.IsFalse(comboBox.Contains("item 4"));
        }

        [Test]
        public void TestGetItem()
        {
            ComboBox comboBox = window.Get<ComboBox>("comboBox1");
            ComboBoxItem item = comboBox.GetItem("item 3");
            Assert.IsNotNull(item);
            Assert.AreEqual("item 3",item.TextValue);
        }

        [Test,ExpectedException(typeof(ElementNotFoundException))]
        public void TestGetItemNotExisting()
        {
            ComboBox comboBox = window.Get<ComboBox>("comboBox1");
            ComboBoxItem item = comboBox.GetItem("item 4");
        }

        [Test]
        public void TestGetItemWithStringIndexer()
        {
            ComboBox comboBox = window.Get<ComboBox>("comboBox1");
            ComboBoxItem item = comboBox["item 2"];
            Assert.IsNotNull(item);
            Assert.AreEqual("item 2", item.TextValue);
        }

        [Test, ExpectedException(typeof(ElementNotFoundException))]
        public void TestGetItemNotExistingWithStringIndexer()
        {
            ComboBox comboBox = window.Get<ComboBox>("comboBox1");
            ComboBoxItem item = comboBox["item 4"];
        }

        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TestGetItemWithStringIndexerWithNullValue()
        {
            ComboBox comboBox = window.Get<ComboBox>("comboBox1");
            ComboBoxItem item = comboBox[null];
        }
    }
}
