﻿
using System;
using Guia.Elements;
using NUnit.Framework;
using WpfTestApplication;
using Guia.Core;
using System.Windows.Automation;

namespace NUnitTests{
    [TestFixture]
    public class ContextMenuTest : AbstractWindowTest
    {
        public ContextMenuTest()
        {
        }

        protected override Type TestWindowType()
        {
            return typeof(ContextMenuTestWindow);
        }

        protected override string TestWindowName()
        {
            return "ContextMenuTestWindow";
        }

        [Test]
        [ExpectedException(typeof(ElementNotFoundException))]
        public void TestShowContextMenuNotFound()
        {
            ContextMenu cm = window.Get<ContextMenu>("cm");
            Assert.IsNull(cm);
        }

        [Test]
        public void TestShowContextMenuAfterRightClick()
        {
            window.Get<ListBox>("listBox").ClickRight();
            ContextMenu cm = window.Get<ContextMenu>("cm");
            Assert.IsNotNull(cm);
        }

        [Test]
        public void TestContextMenuClickAction()
        {
            window.Get<ListBox>("listBox").ClickRight();
            window.Get<ContextMenu>("cm")["miCopy"].Invoke();
            Assert.AreEqual("Copy", window.Get<Label>("labelContextMenuClicked").TextValue);
        }

        [Test]
        public void TestContextMenuClickActionSubmenu()
        {
            window.Get<ListBox>("listBox").ClickRight();
            window.Get<ContextMenu>("cm")["miFurther"]["miFurther1"].Invoke();
            Assert.AreEqual("Action1", window.Get<Label>("labelContextMenuClicked").TextValue);
        }

        [Test]
        public void TestContextMenuClickActionSubmenuParentWindow()
        {
            ListBox listBox = window.Get<ListBox>("listBox");
            listBox.ClickRight();
            Window parentWindow = new Window(listBox.ParentWindow.AutomationElement);
            parentWindow.Get<ContextMenu>("cm")["miFurther"]["miFurther1"].Invoke();
            Assert.AreEqual("Action1", window.Get<Label>("labelContextMenuClicked").TextValue);
        }

        [Test]
        [ExpectedException(typeof(ElementNotEnabledException))]
        public void TestContextMenuClickMenuDisabled()
        {
            window.Get<ListBox>("listBox").ClickRight();
            window.Get<ContextMenu>("cm")["miFurther"]["miFurther2"].Invoke();
        }

        [Test]
        public void TestContextMenuClickMenuCheckUnCheck()
        {
            window.Get<ListBox>("listBox").ClickRight();
            window.Get<ContextMenu>("cm")["miOptions"]["miOption1"].Check();
            Assert.IsTrue(window.Get<ContextMenu>("cm")["miOptions"]["miOption1"].IsChecked);
            window.Get<ListBox>("listBox").ClickRight();
            window.Get<ContextMenu>("cm")["miOptions"]["miOption1"].UnCheck();
            Assert.IsFalse(window.Get<ContextMenu>("cm")["miOptions"]["miOption1"].IsChecked);
        }
    }
}
