namespace NUnitTests{
    using System;
    using System.Threading;
    using System.Windows.Automation;
    using Guia.Core;
    using Guia.Elements;
    using NUnit.Framework;
    using WpfTestApplication;

    [TestFixture]
    public class WindowTest : AbstractWindowTest
    {

        protected override Type TestWindowType()
        {
            return typeof(WindowTestWindow);
        }

        protected override string TestWindowName()
        {
            return "WindowTestWindow";
        }

        [Test, ExpectedException(typeof(OperationNotSupportedException))]
        public void TestMaximizeNotAllowed()
        {
            WindowControl window2 = WindowControl.Start<WindowTestWindow2>();
            try
            {
                window2.Maximize();
            }
            finally
            {
                window2.Stop();
            }
        }

        [Test]
        public void TestMaximizedWindow()
        {
            Assert.IsNotNull(window);
            window.Maximize();
            Assert.AreEqual(WindowVisualState.Maximized, window.GetVisualState());
        }

        [Test]
        public void TestRecoverMaximized()
        {
            Assert.IsNotNull(window);
            window.Maximize();
            Assert.AreEqual(WindowVisualState.Maximized, window.GetVisualState());
            // now, recover to normal
            window.RecoverNormal();
            Assert.AreEqual(WindowVisualState.Normal, window.GetVisualState());
        }

        [Test]
        public void TestClose()
        {
            Assert.IsNotNull(window);
            window.Close();
            Delay.ForMilliseconds(100);
            // Depending on executing-method, other exceptions are thrown.
            // This is probably caused by the different dispatcher handlings. 
            // A Close-event of an application forces the dispatcher to shutdown. 
            // In WindowControl-mode, the dispatcher-shutdown is made in the 
            // test-teardown, thus the patterns are still accessable, hence
            // the exception occures later.
            try
            {
                window.GetVisualState();
                Assert.Fail("Window still open");
            } catch (OperationNotSupportedException)
            {
                // Application
                Assert.IsTrue(true, "Window was closed");
            } catch (ElementNotAvailableException)
            {
                // WindowControl
                Assert.IsTrue(true, "Window was closed");
            }
        }

        [Test]
        public void TestMinimize()
        {
            Assert.IsNotNull(window);
            window.Minimize();
            Assert.AreEqual(WindowVisualState.Minimized, window.GetVisualState());
        }

        [Test, ExpectedException(typeof(OperationNotSupportedException))]
        public void TestMinimizeNotAllowed()
        {
            WindowControl window2 = WindowControl.Start<WindowTestWindow2>();
            try
            {
                window2.Minimize();
            }
            finally
            {
                window2.Stop();
            }
        }

        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TestGetMessageBoxWithNullValue()
        {
            this.window.GetMessageBox(null);
        }

        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TestGetMenuWithNullValue()
        {
            this.window.GetMenu(null);
        }

        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TestGetSaveFileDialogWithNullValue()
        {
            this.window.GetSaveFileDialog(null);
        }

        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TestGetOpenFileDialogWithNullValue()
        {
            this.window.GetOpenFileDialog(null);
        }
    }
}
