namespace Guia.Win32
{
    using System.Drawing;
    using System.Runtime.InteropServices;

    /// <summary>
    /// Helper class to simulate mouse events.
    /// </summary>
    public static class MouseHelper
    {
        /// <summary>
        /// User32 function to simulate a mouse event.
        /// </summary>
        /// <param name="dwFlags">
        /// The dw flags.
        /// </param>
        /// <param name="dx">
        /// The dx.
        /// </param>
        /// <param name="dy">
        /// The dy.
        /// </param>
        /// <param name="cButtons">
        /// The c buttons.
        /// </param>
        /// <param name="dwExtraInfo">
        /// The dw extra info.
        /// </param>
        [DllImport("user32.dll", CharSet = CharSet.Auto, CallingConvention = CallingConvention.StdCall)]
        public static extern void mouse_event(long dwFlags, long dx, long dy, long cButtons, long dwExtraInfo);

        /// <summary>
        /// Simulates a click with the left mouse button on the given position.
        /// </summary>
        /// <param name="x">
        /// The x position.
        /// </param>
        /// <param name="y">
        /// The y position.
        /// </param>
        public static void DoMouseLeftClick(int x, int y)
        {
            // Move the cursor into the position first
            System.Windows.Forms.Cursor.Position = new Point(x, y);
            mouse_event((int)MouseEvent.LEFT_DOWN | (int)MouseEvent.LEFT_UP, x, y, 0, 0);
        }

        /// <summary>
        /// Simulates a click with the right mouse button on the given position.
        /// </summary>
        /// <param name="x">
        /// The x position.
        /// </param>
        /// <param name="y">
        /// The y position.
        /// </param>
        public static void DoMouseRightClick(int x, int y)
        {
            // Move the cursor into the position first
            System.Windows.Forms.Cursor.Position = new Point(x, y);
            mouse_event((int)MouseEvent.RIGHT_DOWN | (int) MouseEvent.RIGHT_UP, x, y, 0, 0);
        }
    }
}