﻿using WpfTestApplication;

namespace GuiaTest
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using Guia.Core;
    using Guia.Elements;
    using Microsoft.VisualStudio.TestTools.UnitTesting;

    /// <summary>
    /// Summary description for SliderTest
    /// </summary>
    [TestClass]
    public class SliderTest : AbstractWindowTest
    {

        #region Overrides of AbstractWindowTest

        protected override Type TestWindowType()
        {
            return typeof(SliderTestWindow);
        }

        protected override string TestWindowName()
        {
            return "SliderTestWindow";
        }

        #endregion

        [TestMethod]
        public void TestMinimum()
        {
            Slider slider = window.Get<Slider>("slider1");
            Assert.AreEqual(-5, slider.Minimum);
        }

        [TestMethod]
        public void TestMaximum()
        {
            Slider slider = window.Get<Slider>("slider1");
            Assert.AreEqual(15,slider.Maximum);
        }

        [TestMethod]
        public void TestSmallChange()
        {
            Slider slider = window.Get<Slider>("slider1");
            Assert.AreEqual(0.1,slider.SmallChange);
        }

        [TestMethod]
        public void TestLargeChange()
        {
            Slider slider = window.Get<Slider>("slider1");
            Assert.AreEqual(1,slider.LargeChange);
        }

        [TestMethod]
        public void TestSmallIncrease()
        {
            Slider slider = window.Get<Slider>("slider1");
            slider.SmallIncrease();
            Assert.AreEqual(0.1,slider.Value);
        }

        [TestMethod]
        public void TestSmallDecrease()
        {
            Slider slider = window.Get<Slider>("slider1");
            slider.SmallDecrease();
            Assert.AreEqual(-0.1, slider.Value);
        }

        [TestMethod]
        public void TestLargeIncrease()
        {
            Slider slider = window.Get<Slider>("slider1");
            slider.LargeIncrease();
            Assert.AreEqual(1,slider.Value);
        }

        [TestMethod]
        public void TestLargeDecrease()
        {
            Slider slider = window.Get<Slider>("slider1");
            slider.LargeDecrease();
            Assert.AreEqual(-1, slider.Value);
        }

        [TestMethod, ExpectedException(typeof(OperationNotSupportedException))]
        public void TestToLargeValue()
        {
            Slider slider = window.Get<Slider>("slider1");
            slider.Value = 20;
        }

        [TestMethod, ExpectedException(typeof(OperationNotSupportedException))]
        public void TestToSmallValue()
        {
            Slider slider = window.Get<Slider>("slider1");
            slider.Value = -10;
        }

        [TestMethod, ExpectedException(typeof(OperationNotSupportedException))]
        public void TestSmallIncreaseInvalidValue()
        {
            Slider slider = window.Get<Slider>("slider1");
            slider.Value = 15;
            slider.SmallIncrease();
        }

        [TestMethod, ExpectedException(typeof(OperationNotSupportedException))]
        public void TestSmallDecreaseInvalidValue()
        {
            Slider slider = window.Get<Slider>("slider1");
            slider.Value = -5;
            slider.SmallDecrease();
        }

        [TestMethod, ExpectedException(typeof(OperationNotSupportedException))]
        public void TestLargeIncreaseInvalidValue()
        {
            Slider slider = window.Get<Slider>("slider1");
            slider.Value = 14.5;
            slider.LargeIncrease();
        }

        [TestMethod, ExpectedException(typeof(OperationNotSupportedException))]
        public void TestLargeDecreaseInvalidValue()
        {
            Slider slider = window.Get<Slider>("slider1");
            slider.Value = -4.9;
            slider.LargeDecrease();
        }

        [TestMethod, ExpectedException(typeof(OperationNotSupportedException))]
        public void TestSetValueSliderDisabled()
        {
            Slider slider = window.Get<Slider>("slider2");
            slider.Value = 1;
        }
    }
}
