namespace NUnitTests{
    using System;
    using System.Collections.Generic;
    using System.Globalization;
    using System.Linq;
    using System.Text;
    using System.Threading;
    using Guia.Config;
    using NUnit.Framework;

    /// <summary>
    /// Summary description for AppConfigImplTest
    /// </summary>
    [TestFixture]
    public class AppConfigImplTest : AbstractTest
    {
        private static IConfig config = AppConfigImpl.Instance;

        [Test]
        public void TestElementTimeout()
        {
            Assert.AreEqual(1500, config.ElementTimeout);
        }

        [Test]
        public void TestWindowTimeout()
        {
            Assert.AreEqual(15000, config.WindowTimeout);
        }

        [Test]
        public void TestCloseModalWindowsTimeout()
        {
            Assert.AreEqual(5000, config.CloseModalWindowsTimeout);
        }

        [Test]
        public void TestGetOpenFileDefaultTitleGerman()
        {
            CultureInfo oldCulture = Thread.CurrentThread.CurrentCulture;
            CultureInfo oldUICulture = Thread.CurrentThread.CurrentUICulture;
            try
            {
                Thread.CurrentThread.CurrentCulture = CultureInfo.GetCultureInfo("de-DE");
                Thread.CurrentThread.CurrentUICulture = Thread.CurrentThread.CurrentCulture;
                string localString = config.GetLocalizedName(EElementIdentifier.OPEN_FILE_DEFAULT_TITLE);
                Assert.AreEqual("Öffnen", localString);
            }
            finally
            {
                Thread.CurrentThread.CurrentCulture = oldCulture;
                Thread.CurrentThread.CurrentUICulture = oldUICulture;
            }
        }

        [Test]
        public void TestGetOpenFileDefaultTitleEnglish()
        {
            CultureInfo oldCulture = Thread.CurrentThread.CurrentCulture;
            CultureInfo oldUICulture = Thread.CurrentThread.CurrentUICulture;
            try
            {
                Thread.CurrentThread.CurrentCulture = CultureInfo.GetCultureInfo("en-GB");
                Thread.CurrentThread.CurrentUICulture = Thread.CurrentThread.CurrentCulture;
                string localString = config.GetLocalizedName(EElementIdentifier.OPEN_FILE_DEFAULT_TITLE);
                Assert.AreEqual("Open", localString);
            }
            finally 
            {
                Thread.CurrentThread.CurrentCulture = oldCulture;
                Thread.CurrentThread.CurrentUICulture = oldUICulture;
            }
        }

        [Test]
        public void TestGetSaveFileDefaultTitleGerman()
        {
            CultureInfo oldCulture = Thread.CurrentThread.CurrentCulture;
            CultureInfo oldUICulture = Thread.CurrentThread.CurrentUICulture;
            try
            {
                Thread.CurrentThread.CurrentCulture = CultureInfo.GetCultureInfo("de-DE");
                Thread.CurrentThread.CurrentUICulture = Thread.CurrentThread.CurrentCulture;
                string localString = config.GetLocalizedName(EElementIdentifier.SAVE_FILE_DEFAULT_TITLE);
                Assert.AreEqual("Speichern unter", localString);
            }
            finally
            {
                Thread.CurrentThread.CurrentCulture = oldCulture;
                Thread.CurrentThread.CurrentUICulture = oldUICulture;
            }
        }

        [Test]
        public void TestGetSaveFileDefaultTitleEnglish()
        {
            CultureInfo oldCulture = Thread.CurrentThread.CurrentCulture;
            CultureInfo oldUICulture = Thread.CurrentThread.CurrentUICulture;
            try
            {
                Thread.CurrentThread.CurrentCulture = CultureInfo.GetCultureInfo("en-GB");
                Thread.CurrentThread.CurrentUICulture = Thread.CurrentThread.CurrentCulture;
                string localString = config.GetLocalizedName(EElementIdentifier.SAVE_FILE_DEFAULT_TITLE);
                Assert.AreEqual("Save As", localString);
            }
            finally
            {
                Thread.CurrentThread.CurrentCulture = oldCulture;
                Thread.CurrentThread.CurrentUICulture = oldUICulture;
            }
        }
    }
}
